@@ -1,11 +1,11 @@
 # ABSTRACT: The base class for all IO::Storm Spout.
 
 package IO::Storm::Spout;
-$IO::Storm::Spout::VERSION = '0.09';
+$IO::Storm::Spout::VERSION = '0.10';
 use Moo;
 use namespace::clean;
 
-extends 'IO::Storm';
+extends 'IO::Storm::Component';
 
 
 sub initialize {
@@ -90,7 +90,7 @@ IO::Storm::Spout - The base class for all IO::Storm Spout.
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 NAME
 
@@ -190,7 +190,7 @@ Cory G Watson <gphat@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Infinity Interactive, Inc.
+This software is copyright (c) 2014 by Educational Testing Service.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
